@@ -13,15 +13,14 @@
 package Directory::Queue::Null;
 use strict;
 use warnings;
-our $VERSION  = "1.10";
-our $REVISION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+our $VERSION  = "1.5";
+our $REVISION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
 
 #
 # used modules
 #
 
-use Directory::Queue qw();
-use No::Worries::Die qw(dief);
+use Directory::Queue qw(_fatal);
 
 #
 # inheritance
@@ -50,7 +49,7 @@ sub first : method {
     return("");
 }
 
-sub next : method { ## no critic 'ProhibitBuiltinHomonyms'
+sub next : method {
     return("");
 }
 
@@ -72,7 +71,7 @@ sub add_ref : method {
 sub add_path : method {
     my($self, $path) = @_;
 
-    unlink($path) or dief("cannot unlink(%s): %s", $path, $!);
+    unlink($path) or _fatal("cannot unlink(%s): %s", $path, $!);
     return("");
 }
 
@@ -81,31 +80,31 @@ sub add_path : method {
 #
 
 sub touch : method {
-    dief("unsupported method: touch()");
+    _fatal("unsupported method: touch()");
 }
 
-sub lock : method { ## no critic 'ProhibitBuiltinHomonyms'
-    dief("unsupported method: lock()");
+sub lock : method {
+    _fatal("unsupported method: lock()");
 }
 
 sub unlock : method {
-    dief("unsupported method: unlock()");
+    _fatal("unsupported method: unlock()");
 }
 
 sub remove : method {
-    dief("unsupported method: remove()");
+    _fatal("unsupported method: remove()");
 }
 
 sub get : method {
-    dief("unsupported method: get()");
+    _fatal("unsupported method: get()");
 }
 
 sub get_ref : method {
-    dief("unsupported method: get_ref()");
+    _fatal("unsupported method: get_ref()");
 }
 
 sub get_path : method {
-    dief("unsupported method: get_path()");
+    _fatal("unsupported method: get_path()");
 }
 
 1;
@@ -126,21 +125,23 @@ Directory::Queue::Null - object oriented interface to a null directory based que
 
 =head1 DESCRIPTION
 
-The goal of this module is to offer a "null" queue system using the same API
-as the other directory queue implementations. The queue will behave like a
-black hole: added data will disappear immediately so the queue will therefore
-always appear empty.
+The goal of this module is to offer a "null" queue system using the
+same API as the other directory queue implementations. The queue will
+behave like a black hole: added data will disappear immediately so the
+queue will therefore always appear empty.
 
-This can be used for testing purposes or to discard data like one would do on
-Unix by redirecting output to C</dev/null>.
+This can be used for testing purposes or to discard data like one
+would do on Unix by redirecting output to C</dev/null>.
 
-Please refer to L<Directory::Queue> for general information about directory
-queues.
+Please refer to L<Directory::Queue> for general information about
+directory queues.
 
 =head1 CONSTRUCTOR
 
-The new() method can be used to create a Directory::Queue::Null object that
-will later be used to interact with the queue. No attributes are supported.
+The new() method can be used to create a Directory::Queue::Null object
+that will later be used to interact with the queue. No attributes are
+supported.
+
 
 =head1 METHODS
 
@@ -178,7 +179,8 @@ return the next element in the queue, so always an empty string
 
 =item add(DATA)
 
-add the given data (it can be anything) to the queue, this does nothing
+add the given data (it can be anything) to the queue, this does
+nothing
 
 =item add_ref(REF)
 
@@ -186,8 +188,8 @@ add the given data reference to the queue, this does nothing
 
 =item add_path(PATH)
 
-add the given file (identified by its path) to the queue, this will therefore
-B<remove> the file
+add the given file (identified by its path) to the queue, this will
+therefore B<remove> the file
 
 =item purge()
 
@@ -195,9 +197,9 @@ purge the queue, this does nothing
 
 =back
 
-The following methods are available to provide the same API as the other
-directory queue modules but they will always return an error as they cannot be
-legitimately called since the queue is always empty:
+The following methods are available to provide the same API as the
+other directory queue modules but they will always return an error as
+they cannot be legitimately called since the queue is always empty:
 
 =over
 
@@ -231,4 +233,4 @@ L<Directory::Queue::Simple>.
 
 Lionel Cons L<http://cern.ch/lionel.cons>
 
-Copyright (C) CERN 2010-2018
+Copyright CERN 2012
